/*!
 * OpenUI5
 * (c) Copyright 2009-2024 SAP SE or an SAP affiliate company.
 * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
 */
sap.ui.define(["sap/m/p13n/modules/AdaptationProvider","sap/base/util/merge","sap/base/Log","sap/m/p13n/modification/FlexModificationHandler","sap/m/p13n/MessageStrip","sap/ui/core/Element","sap/ui/core/ElementRegistry","sap/ui/core/message/MessageType","sap/m/p13n/modules/DefaultProviderRegistry","sap/m/p13n/modules/UIManager","sap/m/p13n/modules/StateHandlerRegistry","sap/m/p13n/modules/xConfigAPI","sap/m/p13n/enums/ProcessingStrategy"],(t,e,n,o,r,i,s,a,c,l,g,h,p)=>{"use strict";const d="Engine: This class is a singleton. Please use the getInstance() method instead.";const f=new WeakMap;let y;const u=t.extend("sap.m.p13n.Engine",{constructor:function(){t.call(this);if(y){throw Error(d)}this._aRegistry=[];this._aStateHandlers=[];this.defaultProviderRegistry=c.getInstance(this);this.uimanager=l.getInstance(this);this.stateHandlerRegistry=g.getInstance()}});u.prototype.register=function(t,e){if(!e.hasOwnProperty("controller")){throw new Error("Please provide at least a configuration 'controller' containing a map of key-value pairs (key + Controller class) in order to register adaptation.")}let n=this._getRegistryEntry(t);if(n){this.deregister(t)}n=this._createRegistryEntry(t,e);const o=Object.keys(e.controller);o.forEach(n=>{const o=e.controller[n];if(!this.getController(t,n)){if(this._aRegistry.indexOf(t.getId())<0){this._aRegistry.push(t.getId())}this.addController(o,n)}});const r=t.getCustomData().find(t=>t.getKey()=="xConfig");if(r&&JSON.parse(r.getValue().replace(/\\/g,""))?.modified){this.fireStateChange(t)}};u.prototype.deregister=function(t){const e=this._getRegistryEntry(t);Object.keys(e.controller).forEach(t=>{const n=e.controller[t];n.destroy();delete e.controller[t]});f.delete(t);const n=this._aRegistry.indexOf(t.getId());this._aRegistry.splice(n,1)};u.prototype.show=async function(t,e,n){const o=await this.hasChanges(t,e).catch(t=>false);const r=await this.uimanager.show(t,e,{...n,enableReset:o});return r.getParent()};u.prototype.attachStateChange=function(t){return this.stateHandlerRegistry.attachChange(t)};u.prototype.detachStateChange=function(t){return this.stateHandlerRegistry.detachChange(t)};u.prototype.hasChanges=function(t,e){const n=this.getController(t,e)?.getChangeOperations();let o;if(n){o=[];Object.values(n).forEach(t=>{if(Array.isArray(t)){o=o.concat(t)}else{o.push(t)}})}let r=[];if(this.getController(t,e)?.getSelectorsForHasChanges){r=r.concat(this.getController(t,e).getSelectorsForHasChanges())}else{r.push(t)}const i=this._determineModification(t);return this.getModificationHandler(t).hasChanges({selector:t,selectors:r,changeTypes:o},i?.payload).then(t=>t)};u.prototype.reset=function(t,e){if(e===undefined){e=this.getRegisteredControllers(t)}e=e instanceof Array?e:[e];let n=[];e.forEach(e=>{n=n.concat(this.getController(t,e).getSelectorForReset())});const o={selectors:n,selector:t};if(e){let n=[];e.forEach(e=>{n=n.concat(Object.values(this.getController(t,e).getChangeOperations()))});o.changeTypes=[].concat(...n)}const r=this._determineModification(t);return r.handler.reset(o,r.payload).then(()=>this.initAdaptation(t,e).then(n=>{e.forEach(e=>{const o=this.getController(t,e);o.update(n)})}))};u.prototype.applyState=function(t,e){return this.retrieveState(t).then(o=>{const r=[];let i=[];let s={};if(t.validateState instanceof Function){s=t.validateState(this.externalizeKeys(t,e))}if(s.validation===a.Error){n.error(s.message)}const c=Object.keys(e);c.forEach(n=>{const o=this.getController(t,n);if(!o){return}const i=this.createChanges({control:t,key:n,state:o.sanityCheck(e[n]),suppressAppliance:true,applyAbsolute:false});r.push(i)});return Promise.all(r).then(e=>{const n={};e.forEach((t,e)=>{if(t&&t.length>0){i=i.concat(t);const o=c[e];n[o]=t}});return this._processChanges(t,n)})})};u.prototype.retrieveState=function(t){return this.checkControlInitialized(t).then(()=>u.getInstance().waitForChanges(t).then(()=>{const n={};u.getInstance().getRegisteredControllers(t).forEach(e=>{n[e]=u.getInstance().getController(t,e).getCurrentState(true)});return e({},n)}))};u.prototype._setModificationHandler=function(t,e){if(!e.isA("sap.m.p13n.modification.ModificationHandler")){throw new Error("Only sap.m.p13n.modification.ModificationHandler derivations are allowed for modification")}const n=this._determineModification(t);n.handler=e;this._getRegistryEntry(t).modification=n};u.prototype._addToQueue=function(t,e){const n=this._getRegistryEntry(t);const o=t=>{if(n.pendingModification===t){n.pendingModification=null}};n.pendingModification=n.pendingModification instanceof Promise?n.pendingModification.then(e):e();n.pendingModification.then(o.bind(null,n.pendingModification));return n.pendingModification};u.prototype.createChanges=function(t){const n=u.getControlInstance(t.control);const o=t.key;const r=t.state;const i=!!t.suppressAppliance;if(!o||!t.control||!r){return Promise.resolve([])}const s=()=>this.initAdaptation(n,o).then(()=>r).then(r=>{const s=this.getController(n,o);const a=s.getChangeOperations();const c=this._getRegistryEntry(n);const l=s.getCurrentState();const g=e(l instanceof Array?[]:{},l);const h=s.getMetadataHelper();const p=h?h:c.helper;const d=p.getProperties().map(t=>({key:t.key,name:t.name}));const f={existingState:t.stateBefore||g,applyAbsolute:t.applyAbsolute,changedState:r,control:s.getAdaptationControl(),changeOperations:a,deltaAttributes:["key"],propertyInfo:d};const y=s.getDelta(f);if(!i){const t={};t[o]=y;return this._processChanges(n,t).then(()=>y)}return y||[]});return this._addToQueue(n,s)};u.prototype.waitForChanges=function(t){const e=this._determineModification(t);const n=this._getRegistryEntry(t);return n&&n.pendingModification?n.pendingModification:Promise.resolve().then(()=>e.handler.waitForChanges({element:t},e.payload))};u.prototype.isModificationSupported=function(t){const e=this._determineModification(t);return e.handler.isModificationSupported({element:t},e.payload)};u.prototype.fireStateChange=function(t){return this.retrieveState(t).then(e=>{this.stateHandlerRegistry.fireChange(t,e)})};u.prototype._processChanges=function(t,e){let n=[];const o=Object.keys(e);const r={};o.forEach(o=>{r[o]=this.getController(t,o).changesToState(e[o]);n=n.concat(e[o])});if(n instanceof Array&&n.length>0){const e=this._determineModification(t);return e.handler.processChanges(n,e.payload)}else{return Promise.resolve([])}};u.prototype.getRTASettingsActionHandler=function(t,e,n){let r;const i=this.hasForReference(t,"sap.m.p13n.PersistenceProvider");if(i.length>0&&!t.isA("sap.ui.mdc.link.Panel")){return Promise.reject("Please do not use a PeristenceProvider in RTA.")}const s=this.getModificationHandler(t);const a=new o;const c=new Promise((t,e)=>{r=t});a.processChanges=t=>{r(t);return Promise.resolve(t)};this._setModificationHandler(t,a);this.uimanager.show(t,n,{showReset:false}).then(t=>{const n=t.getCustomHeader();if(n){n.getContentRight()[0].setVisible(false)}t.addStyleClass(e.styleClass);if(e.fnAfterClose instanceof Function){t.attachAfterClose(e.fnAfterClose)}});c.then(()=>{this._setModificationHandler(t,s);a.destroy()});return c};u.prototype.enhanceXConfig=function(t,e){const n=u.getControlInstance(t);const o=this._getRegistryEntry(t);const r=e&&e.value&&e.value.controllerKey?e.value.controllerKey:undefined;e.currentState=u.getInstance().getController(n,e.changeType,r)?.getCurrentState();return h.enhanceConfig(n,e).then(t=>{if(o){o.xConfig=t}return t})};u.prototype.readXConfig=(t,e)=>{const n=u.getControlInstance(t);return h.readConfig(n,e)||{}};u.prototype.externalizeKeys=function(t,e){const n={};Object.keys(e).forEach(o=>{const r=this.getController(u.getControlInstance(t),o);if(r){n[r.getStateKey()]=e[o]}});return n};u.prototype.internalizeKeys=function(t,e){const n=this.getRegisteredControllers(t),o={};n.forEach(n=>{const r=this.getController(t,n).getStateKey();if(e.hasOwnProperty(r)){o[n]=e[r]}});return o};u.prototype.diffState=function(t,n,o){const r=[],i={};n=e({},n);o=e({},o);Object.keys(o).forEach(e=>{r.push(this.createChanges({control:t,stateBefore:n[e],state:this.getController(t,e).sanityCheck(o[e]),applyAbsolute:p.FullReplace,key:e,suppressAppliance:true}))});return Promise.all(r).then(e=>{Object.keys(o).forEach((r,s)=>{if(o[r]){const a=this.getController(t,r).changesToState(e[s],n[r],o[r]);i[r]=a}});return i})};u.prototype.checkControlInitialized=t=>{const e=u.getControlInstance(t);const n=e.initialized instanceof Function?e.initialized():Promise.resolve();return n||Promise.resolve()};u.prototype.checkPropertyHelperInitialized=t=>{const e=u.getControlInstance(t);return e.initPropertyHelper instanceof Function?e.initPropertyHelper():Promise.resolve()};u.prototype.initAdaptation=function(t,e){this.verifyController(t,e);const n=this._getRegistryEntry(t);const o=u.getControlInstance(t);if(n.helper){return Promise.resolve(n.helper)}return this.checkPropertyHelperInitialized(o).then(t=>{n.helper=t;return t},t=>{throw new Error(t)})};u.prototype.addController=function(t,e,n){const o=this._getRegistryEntry(t.getAdaptationControl(),n);o.controller[e]=t};u.prototype.getController=function(t,e,n){const o=this._getRegistryEntry(t);let r;if(o&&o.controller.hasOwnProperty(e)){r=o.controller[e]}if(r){return r}this.getRegisteredControllers(t).forEach(o=>{const i=this.getController(t,o);if(i){Object.keys(i.getChangeOperations()).forEach(t=>{if(i.getChangeOperations()[t]===e){if(!n||n===i.getPersistenceIdentifier()){r=i}}})}});return r};u.prototype.verifyController=function(t,e){const n=e instanceof Array?e:[e];n.forEach(e=>{if(!this.getController(t,e)){const n=u.getControlInstance(t);throw new Error("No controller registered yet for "+n.getId()+" and key: "+e)}})};u.prototype.getUISettings=function(t,e){const n=Array.isArray(e)?e:[e];this.verifyController(t,n);const o=this._getRegistryEntry(t).helper;const r={},i=[];n.forEach(e=>{const n=this.getController(t,e);const r=n.initAdaptationUI(o);if(r instanceof Promise){i.push(r)}});return Promise.all(i).then(t=>{t.forEach((t,e)=>{const o=n[e];r[o]={panel:t}});return r})};u.prototype.isRegistered=function(t){const e=this._getRegistryEntry(t);return!!e};u.prototype.isRegisteredForModification=function(t){const e=this._getRegistryEntry(t);return e&&!!e.modification};u.prototype.getRegisteredControllers=function(t){const e=this._getRegistryEntry(t);return e?Object.keys(e.controller):[]};u.prototype._getRegistryEntry=t=>{const e=u.getControlInstance(t);return f.get(e)};u.prototype.getModificationHandler=function(t){const e=this._determineModification(t);return e.handler};u.prototype._createRegistryEntry=(t,e)=>{const n=u.getControlInstance(t);if(!f.has(n)){f.set(n,{modification:e&&e.modification?{handler:e.modification,payload:{mode:"Auto",hasVM:true,hasPP:false}}:null,controller:{},activeP13n:null,helper:e&&e.helper?e.helper:null,xConfig:null,pendingAppliance:{}})}return f.get(n)};u.prototype.trace=function(t,e){const n=this._getRegistryEntry(t);this.getRegisteredControllers(t).forEach(o=>{const r=this.getController(t,o);const i=r.getChangeOperations();Object.keys(i).forEach(t=>{if(i[t]===e.changeSpecificData.changeType){n.pendingAppliance[o]=[].concat(n.pendingAppliance[o]||[]).concat(e)}})})};u.prototype.getTrace=function(t,e){const n=this._getRegistryEntry(t);let o;if(n){o=Object.keys(n.pendingAppliance)}return o};u.prototype.clearTrace=function(t,e){const n=this._getRegistryEntry(t);if(n){n.pendingAppliance={}}};u.prototype._determineModification=function(t){const e=this._getRegistryEntry(t);if(e&&e.modification){return e.modification}const n=this.hasForReference(t,"sap.m.p13n.PersistenceProvider").concat(this.hasForReference(t,"sap.ui.mdc.p13n.PersistenceProvider"));const r=this.hasForReference(t,"sap.ui.fl.variants.VariantManagement");let i;if(n?.length>1){i=n.find(t=>{const e=Object.values(this.defaultProviderRegistry._mDefaultProviders);return e?.find(e=>e.getId()==t.getId())})}i=i||n?.[0];const s=i?i.getMode():"Standard";const a={handler:o.getInstance(),payload:{hasVM:r&&r.length>0,hasPP:n&&n.length>0,mode:s}};if(e&&!e.modification){e.modification=a}return a};u.prototype.hasForReference=(t,e)=>{const n=t&&t.getId?t.getId():t;const o=s.filter(t=>{if(!t.isA(e)){return false}const o=t.getFor instanceof Function?t.getFor():[];for(let t=0;t<o.length;t++){if(o[t]===n||y.hasControlAncestorWithId(n,o[t])){return true}}return false});return o};u.prototype.hasControlAncestorWithId=(t,e)=>{let n;if(t===e){return true}n=i.getElementById(t);while(n){if(n.getId()===e){return true}if(typeof n.getParent==="function"){n=n.getParent()}else{return false}}return false};u.getControlInstance=t=>typeof t=="string"?i.getElementById(t):t;u.prototype.hasActiveP13n=function(t){return!!this._getRegistryEntry(t).activeP13n};u.prototype.setActiveP13n=function(t,e,n){this._getRegistryEntry(t).activeP13n=e?{usedControllers:e,modified:n}:null};u.prototype.validateP13n=function(t,e,o){const i=this.getController(t,e);const s=u.getControlInstance(t);const c=this._getRegistryEntry(t).controller;const l={};Object.keys(c).forEach(t=>{l[t]=c[t].getCurrentState()});if(i&&i.model2State instanceof Function){l[e]=i.model2State();let t={validation:a.None};if(s.validateState instanceof Function){t=s.validateState(this.externalizeKeys(s,l),e)}let c;if(t.validation!==a.None){c=new r({type:t.validation,text:t.message})}if(o.setMessageStrip instanceof Function){o.setMessageStrip(c)}else{n.warning("message strip could not be provided - the adaptation UI needs to implement 'setMessageStrip'")}}};u.prototype.handleP13n=function(t,e){const n=[];e.forEach(e=>{const o=this.getController(t,e);const r=o.getP13nData();if(r){const i=this.createChanges({control:t,key:e,state:r,suppressAppliance:true,applyAbsolute:true}).then(t=>o.getBeforeApply().then(e=>{const n=e?e.concat(t):t;return n}));n.push(i)}});return Promise.all(n).then(n=>{let o=[];const r={};n.forEach((t,n)=>{o=o.concat(t);const i=e[n];r[i]=t});if(o.length>0){u.getInstance()._processChanges(t,r)}})};u.getInstance=()=>{if(!y){y=new u}return y};u.prototype._getRegistry=function(){const t={stateHandlerRegistry:this.stateHandlerRegistry,defaultProviderRegistry:this.defaultProviderRegistry,controlRegistry:{}};this._aRegistry.forEach(e=>{const n=i.getElementById(e);t.controlRegistry[e]=f.get(n)});return t};u.prototype.destroy=function(){t.prototype.destroy.apply(this,arguments);y=null;this._aRegistry=null;f.delete(this);this.defaultProviderRegistry.destroy();this.defaultProviderRegistry=null;this.stateHandlerRegistry.destroy();this.stateHandlerRegistry=null;this.uimanager.destroy();this.uimanager=null};return u});
//# sourceMappingURL=Engine.js.map